#
# spec file for package SDL2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sle_version 0
Name:           SDL2
%define lname   libSDL2-2_0-0
Version:        2.30.0
Release:        1.1
Summary:        Simple DirectMedia Layer Library
License:        Zlib
Group:          Development/Libraries/X11
URL:            https://libsdl.org/
#Git-Clone:     https://github.com/libsdl-org/SDL
Source:         https://libsdl.org/release/%name-%version.tar.gz
Source2:        https://libsdl.org/release/%name-%version.tar.gz.sig
Source3:        %name.keyring
Source4:        baselibs.conf
Patch1:         sdl2-symvers.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libdecor-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa) >= 1.0.11
BuildRequires:  pkgconfig(dbus-1)
%if !0%{?sle_version}
BuildRequires:  pkgconfig(fcitx)
%endif
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv1_cm)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(ice)
# KMS/DRM driver needs libdrm and libgbm
BuildRequires:  pkgconfig(gbm) >= 11.1.0
BuildRequires:  pkgconfig(libdrm) >= 2.4.82
BuildRequires:  pkgconfig(libpipewire-0.3) >= 0.3.20
BuildRequires:  pkgconfig(libpulse-simple) >= 0.9
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(wayland-client) >= 1.18
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xxf86vm)

%description
This is the "Simple DirectMedia Layer" library. It provides a generic
API for access to audio, keyboard, mouse, and display framebuffer
across multiple platforms.

%package -n %lname
Summary:        Simple DirectMedia Layer Library
Group:          System/Libraries
Provides:       SDL2 = %version-%release

%description -n %lname
This is the "Simple DirectMedia Layer" library. It provides a generic
API for access to audio, keyboard, mouse, and display framebuffer
across multiple platforms.

SDL2 uses dlopen, so if you experience problems under X11, check
again that libXrandr2 and libXi6 are in fact installed.

%package devel
Summary:        SDL2 Library Developer Files
Group:          Development/Libraries/X11
Requires:       %lname = %version-%release
Requires:       c_compiler
Requires:       pkgconfig
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glesv1_cm)
Requires:       pkgconfig(glesv2)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xproto)
Obsoletes:      libSDL2-devel < %version-%release
Provides:       libSDL2-devel = %version-%release

%description devel
This package contains files needed for development with the SDL2
library.

%prep
%autosetup -p1
perl -i -pe 's{\r\n}{\n}g' *.txt README.md

%build
%global _lto_cflags %_lto_cflags -ffat-lto-objects
# In this instance, we do want --with-pic because of libSDL2main.a.
%configure --with-pic --disable-alsa-shared --disable-video-directfb \
	--enable-video-kmsdrm --enable-video-wayland \
%if 0%{?sle_version}
	--disable-fcitx \
%endif
%ifarch ix86
	--enable-sse2=no \
%endif
	--enable-sse3=no --disable-rpath --disable-3dnow
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la
rm -fv "%buildroot/%_libdir/libSDL2.a"
# Need to keep libSDL2main.a (empty lib), because it is referenced by
# sdl2-config.cmake, and it seems like that .cmake file cannot be edited to
# make SDL2::SDL2main a phony target with no file (just leads to more Makefile
# errors down the road).

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license LICENSE.txt
%doc README.md README-SDL.txt
%_libdir/libSDL2-2*.so.*

%files devel
%doc WhatsNew.txt
%_bindir/sdl2-config
%_libdir/libSDL2.so
%_includedir/SDL2/
%_datadir/aclocal/sdl2.m4
%_libdir/pkgconfig/sdl2.pc
%_libdir/cmake/SDL2/
%_libdir/libSDL2main.a
%_libdir/libSDL2_test.a

%changelog
* Fri Feb  2 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.30
  * Added support for 2 bits-per-pixel indexed surface formats.
  * Added the function SDL_GameControllerGetSteamHandle() to get
    the Steam API handle for a controller, if available.
  * Added the event SDL_CONTROLLERSTEAMHANDLEUPDATED which is sent
    when the Steam API handle for a controller changes. This could
    also change the name, VID, and PID of the controller.
  * Added the environment variable SDL_LOGGING to control default
    log output.
* Thu Nov  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.28.5
  * Added support for the HP HyperX Clutch Gladiate controller
  * Fixed a crash if a controller is disconnected while SDL is
    opening it
  * Fixed a crash on Linux if XInput2 isn't available at runtime
* Sat Oct  7 2023 Jan Engelhardt <jengelh@inai.de>
- Enable direct PipeWire support
* Mon Oct  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.28.4
  * Enable clipping for zero sized rectangles in the SDL renderer
  * Notify X11 clipboard managers when the clipboard changes
  * Fixed sensor timestamps for third-party PS5 controllers
  * Added detection for Logitech and Simagic racing wheels
* Fri Sep  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.28.3
  * Added a gamepad mapping for the G-Shark GS-GP702
  * Fixed touchpad events for the Razer Wolverine V2 Pro in PS5 mode
* Wed Aug  2 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.28.2
  * Fixed 8BitDo gamepad mapping when in XInput mode on Linux
  * Fixed controller lockup initializing some unofficial PS4
    replica controllers
  * Fixed video initialization on headless Linux systems using VNC
* Sat Jul  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.28.1
  * Added support for the Nintendo Online Famicom controllers
  * Improved support for third-party Nintendo Switch controllers
  * Fixed setting the player LED on Nintendo Switch controllers
  * Added Linux controller mapping for the Logitech Chillstream
* Wed Jun 21 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.28
  * Added SDL_HasWindowSurface() and SDL_DestroyWindowSurface() to
    switch between the window surface and rendering APIs.
  * Added a display event SDL_DISPLAYEVENT_MOVED which is sent
    when the primary monitor changes or displays change position
    relative to each other.
  * Added the hint SDL_HINT_ENABLE_SCREEN_KEYBOARD to control
    whether the on-screen keyboard should be shown when text input
    is active.
- Delete 0001-Cleanup-add-brace-6545.patch,
  0002-Update-for-SDL3-coding-style-6717.patch,
  0003-Clang-Tidy-fixes-6725.patch (inapplicable),
  0004-evdev_kbd-Use-current-keymap.patch (merged).
* Tue Apr 11 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26.5
  * Fixed handling of third party PS4 controller input reports
  * Added support for the trigger buttons on the Victrix Pro FS
    for PS5
  * Added mapping for Flydigi Vader 2 with the latest firmware
    (6.0.4.9)
  * Added mapping for DualSense Edge Wireless Controller on Linux
  * Added mapping for Hori Pokken Tournament DX Pro Pad
  * Improved the speed and quality of audio resampling
  * Fixed crash on Linux if dbus can't be initialized
* Tue Mar  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26.4
  * Fixed using older game controller mappings on Linux
* Fri Mar  3 2023 Michal Suchanek <msuchanek@suse.com>
- Use current keymap on console
  (https://github.com/libsdl-org/SDL/pull/7400 )
  + 0001-Cleanup-add-brace-6545.patch
  + 0002-Update-for-SDL3-coding-style-6717.patch
  + 0003-Clang-Tidy-fixes-6725.patch
  + 0004-evdev_kbd-Use-current-keymap.patch
* Tue Feb  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26.3
  * Fixed infinite loop shutting down WGI controllers
  * Fixed centering the D-pad on some Xbox controllers
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26.2
  * Fixed long delay at startup when a Razer keyboard is
    connected
  * Fixed not receiving SDLK_5 or SDL_SCANCODE_5 when using the
    AZERTY keyboard layout on Linux
- Enable libsamplerate and libdecor components
- Remove unused tslib build requirement
* Thu Dec  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26.1
  * Improved audio resampling quality
  * Fixed crash if SDL_GetPointDisplayIndex() or
    SDL_GetRectDisplayIndex() are called before SDL_VideoInit()
* Tue Nov 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26
  * Added SDL_GetWindowSizeInPixels() to get the window size in
    pixels, which may differ from the window coordinate size for
    windows with high-DPI support.
  * Added simulated vsync synchronization for the software
    renderer.
  * Added the mouse position to SDL_MouseWheelEvent.
  * Added SDL_ResetHints() to reset all hints to their default
    values.
  * Added SDL_GetJoystickGUIDInfo() to get device information
    encoded in a joystick GUID.
  * Added XBOX Hints.
  * Added support for PS3 and Wii controllers to the HIDAPI
    driver (not enabled by default).
  * Added access to the individual left and right gyro sensors of
    the combined Joy-Cons controller.
  * Added a microsecond timestamp to SDL_SensorEvent and
    SDL_ControllerSensorEvent, when the hardware provides that
    information.
- Delete sdl2-khronos.patch (merged)
- Drop CVE-2022-4743.patch.
* Thu Nov  3 2022 Michael Gorse <mgorse@suse.com>
- Add CVE-2022-4743.patch: fix potential memory leak in
  GLES_CreateTexture (boo#1206727 CVE-2022-4743).
* Tue Nov  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.24.2
  * Fixed crash in Wayland_HasScreenKeyboardSupport()
* Thu Oct 27 2022 Cristian Rodríguez <crrodriguez@opensuse.org>
- Drop unused buildrequires on nasm
* Wed Oct  5 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.24.1
  * Fixed shader compilation issues using the OpenGL ES2 renderer
* Fri Aug 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.24.0
  * Added a number of function relating to input devices such as
    keyboard and joystick.
  * Added support for the NVIDIA Shield Controller to the HIDAPI
    driver, supporting rumble and battery status
  * Added support for opening audio devices with 3 or 5 channels
    (2.1, 4.1). All channel counts from Mono to 7.1 are now
    supported.
- Drop baselibs.conf (no SDL2_ttf-dependent Tumbleweed packages
  themselves have baselibs).
- Drop fix-xi2-crash.patch (merged)
- Rename devel package to just %%name-devel, which is what most
  our packages do.
* Tue Jul  5 2022 Jan Engelhardt <jengelh@inai.de>
- Add fix-xi2-crash.patch
* Fri Apr 29 2022 Jan Engelhardt <jengelh@inai.de>
- Restore sdl2-symvers.patch to full symbol list to facilitate
  application installation with Leap 15.x's SDL2.
* Mon Apr 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.22
  * Added SDL_RenderGetWindow() to get the window associated with a renderer
  * Added floating point rectangle functions: SDL_PointInFRect(),
    SDL_FRectEmpty(), SDL_FRectEquals(), SDL_FRectEqualsEpsilon(),
    SDL_HasIntersectionF(), SDL_IntersectFRect(), SDL_UnionFRect(),
    SDL_EncloseFPoints(), SDL_IntersectFRectAndLine().
  * Added SDL_IsTextInputShown() which returns whether the IME
    window is currently shown.
  * Added SDL_ClearComposition() to dismiss the composition
    window without disabling IME input.
  * Added SDL_TEXTEDITING_EXT event for handling long composition
    text, and a hint SDL_HINT_IME_SUPPORT_EXTENDED_TEXT to enable
    it.
  * Added the hint SDL_HINT_MOUSE_RELATIVE_MODE_CENTER to control
    whether the mouse should be constrained to the whole window
    or the center of the window when relative mode is enabled.
  * The mouse is now automatically captured when mouse buttons
    are pressed, and the hint SDL_HINT_MOUSE_AUTO_CAPTURE allows
    you to control this behavior.
  * Added the hint SDL_HINT_VIDEO_FOREIGN_WINDOW_OPENGL to let
    SDL know that a foreign window will be used with OpenGL.
  * Added the hint SDL_HINT_VIDEO_FOREIGN_WINDOW_VULKAN to let
    SDL know that a foreign window will be used with Vulkan.
  * Added the hint SDL_HINT_QUIT_ON_LAST_WINDOW_CLOSE to specify
    whether an SDL_QUIT event will be delivered when the last
    application window is closed.
  * Added the hint SDL_HINT_JOYSTICK_ROG_CHAKRAM to control
    whether ROG Chakram mice show up as joysticks.
  * Added the hint SDL_HINT_X11_WINDOW_TYPE to specify the
    _NET_WM_WINDOW_TYPE of SDL windows.
  * Added the hint SDL_HINT_VIDEO_WAYLAND_PREFER_LIBDECOR to
    allow using libdecor with compositors that support
    xdg-decoration.
* Sun Jan 16 2022 Carsten Ziepke <kieltux@gmail.com>
- Drop 0001-Fix-build-against-wayland-1.20.patch
  Fixed upstream: https://github.com/libsdl-org/SDL/pull/5092
* Tue Jan 11 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.20
  * SDL_RenderGeometryRaw() takes a pointer to SDL_Color, not
    int. You can cast color data in SDL_PIXELFORMAT_RGBA32 format
    (SDL_PIXELFORMAT_ABGR8888 on little endian systems) for this
    parameter.
  * Improved accuracy of horizontal and vertical line drawing
    when using OpenGL or OpenGLES.
  * Added the hint SDL_HINT_RENDER_LINE_METHOD to control the
    method of line drawing used, to select speed, correctness,
    and compatibility.
* Fri Dec 17 2021 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Fix-build-against-wayland-1.20.patch
* Tue Nov 30 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.18
  * Added SDL_RenderGeometry() and SDL_RenderGeometryRaw() to
    allow rendering of arbitrary shapes using the SDL 2D render
    API.
  * Added SDL_SetTextureUserData() and SDL_GetTextureUserData()
    to associate application data with an SDL texture.
  * Added SDL_RenderWindowToLogical() and
    SDL_RenderLogicalToWindow() to convert between window
    coordinates and logical render coordinates.
  * Added SDL_RenderSetVSync() to change whether a renderer
    present is synchronized with vblank at runtime.
  * Added SDL_PremultiplyAlpha() to premultiply alpha on a block
    of SDL_PIXELFORMAT_ARGB8888 pixels.
  * Added a window event SDL_WINDOWEVENT_DISPLAY_CHANGED which is
    sent when a window changes what display it is centered on.
  * Added SDL_GetWindowICCProfile() to query a window's ICC
    profile, and a window event SDL_WINDOWEVENT_ICCPROF_CHANGED
    that is sent when it changes.
  * Added the hint SDL_HINT_VIDEO_EGL_ALLOW_TRANSPARENCY to allow
    EGL windows to be transparent instead of opaque.
  * Added SDL_SetWindowMouseRect() and SDL_GetWindowMouseRect()
    to confine the mouse cursor to an area of a window.
  * You can now read precise mouse wheel motion using 'preciseX'
    and 'preciseY' event fields.
  * Added SDL_GameControllerHasRumble() and
    SDL_GameControllerHasRumbleTriggers() to query whether a game
    controller supports rumble.
  * Added SDL_JoystickHasRumble() and
    SDL_JoystickHasRumbleTriggers() to query whether a joystick
    supports rumble.
  * SDL's hidapi implementation is now available as a public API
    in SDL_hidapi.h.
- Drop SDL2-endian.patch (inapplicable),
  sdl2-fix-wayland-fullscreen.patch (merged),
  audio-Support-pulse-as-an-alias-for-pulseaudio.patch (merged)
- Drop CVE-2021-33657.patch.
* Wed Nov 10 2021 Michael Gorse <mgorse@suse.com>
- Add CVE-2021-33657.patch: always create a full 256-entry color
  map in case color values are out of range (boo#1198001
  CVE-2021-33657).
* Mon Nov  8 2021 tiwai@suse.de
- Support "pulse" as an alias for pulseaudio (bsc#1191868,
  bsc#1189778):
  audio-Support-pulse-as-an-alias-for-pulseaudio.patch
* Wed Aug 11 2021 kh Lai <dlshcbmuipmam@hotmail.com>
- sdl2-fix-wayland-fullscreen.patch
  * fix wayland issue for wlroot, see https://github.com/libsdl-org/SDL/pull/4629
* Wed Aug 11 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.16
  * Better native Wayland support, including handling for
    client-side decorations and other functionality in place.
  * Support for being able to directly interface with PipeWire for
    audio input/output, a variety of new APIs, support for the
    Amazon Luna game controller, rumble support for more
    controllers.
  * NOTE: Switching away (e.g. with Alt-Tab) from fullscreen
    windows created with the SDL_WINDOW_FULLSCREEN flag will now
    minimize them. If your window manager is configured to now show
    minimzed windows in either the Alt-Tab list or the task bar,
    you will have difficulty unminimizing these windows.
* Wed Dec 23 2020 Dirk Müller <dmueller@suse.com>
- update to 2.0.14:
  * Added support for PS5 DualSense and Xbox Series X controllers to the HIDAPI controller driver
  * Vulkan support to the KMSDRM video driver
  * see details on https://discourse.libsdl.org/t/sdl-2-0-14-released/28470
* Thu Apr 16 2020 Jan Engelhardt <jengelh@inai.de>
- Restore libSDL2main.a, patching it out was not easily possible.
* Wed Mar 11 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.12
  * Support for the Google Stadia controller and other game
    controllers
  * A new video driver for offscreen rendering
  * ARM NEON optimizations
- Drop CVE-2019-13616.patch (merged upstream)
- Drop sdl2-surface-pitch-overflow.patch.
* Tue Jan 14 2020 Michael Gorse <mgorse@suse.com>
- Add sdl2-surface-pitch-overflow.patch: fix overflow in surface
  pitch calculation (boo#1181201 boo#1181202 CVE-2020-14410
  CVE-2020-14409).
* Sun Jan 12 2020 Jan Engelhardt <jengelh@inai.de>
- Temporarily work around -fno-common build failure [boo#1160382].
* Wed Oct  9 2019 Stefan Dirsch <sndirsch@suse.com>
- sdl2-khronos.patch
  * fixes build on i586 (boo#1153455, boo#1158176)
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Update sdl2-symvers.patch for SDL 2.0.9/2.0.10.
* Thu Aug 22 2019 Michael Gorse <mgorse@suse.com>
- Add CVE-2019-13616.patch: fix heap buffer overflow when reading
  a crafted bmp file (boo#1141844 CVE-2019-13616).
* Sun Aug 11 2019 Jan Engelhardt <jengelh@inai.de>
- Drop libSDL2main.a from libSDL-2_0-devel. It is only used
  during build.
* Wed Jul 31 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static library.
* Fri Jul 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.10
  * The SDL_RW* macros have been turned into functions that are
    available only in 2.0.10 and onward
  * Added SDL_SIMDGetAlignment(), SDL_SIMDAlloc(), and
    SDL_SIMDFree(), to allocate memory aligned for SIMD
    operations for the current CPU
  * Added SDL_RenderDrawPointF(), SDL_RenderDrawPointsF(),
    SDL_RenderDrawLineF(), SDL_RenderDrawLinesF(),
    SDL_RenderDrawRectF(), SDL_RenderDrawRectsF(),
    SDL_RenderFillRectF(), SDL_RenderFillRectsF(),
    SDL_RenderCopyF(), SDL_RenderCopyExF(), to allow floating
    point precision in the SDL rendering API.
  * Added SDL_GetTouchDeviceType() to get the type of a touch
    device, which can be a touch screen or a trackpad in relative
    or absolute coordinate mode.
  * The SDL rendering API now uses batched rendering by default,
    for improved performance
  * Added SDL_RenderFlush() to force batched render commands to
    execute, if you're going to mix SDL rendering with native
    rendering
  * Added the hint SDL_HINT_RENDER_BATCHING to control whether
    batching should be used for the rendering API. This defaults
    to "1" if you don't specify what rendering driver to use when
    creating the renderer.
  * Added the hint SDL_HINT_EVENT_LOGGING to enable logging of
    SDL events for debugging purposes
  * Added the hint SDL_HINT_GAMECONTROLLERCONFIG_FILE to specify
    a file that will be loaded at joystick initialization with
    game controller bindings
  * Added the hint SDL_HINT_MOUSE_TOUCH_EVENTS to control
    whether SDL will synthesize touch events from mouse events
  * Improved handling of malformed WAVE and BMP files, fixing
    potential security exploits (boo#1142031 CVE-2019-13626)
  * Removed the Mir video driver in favor of Wayland
  * Security fixes: CVE-2019-7635 (boo#1124827), CVE-2019-7636
    (boo#1124826), CVE-2019-7638 (boo#1124824).
- Refreshed sdl2-symvers.patch
- Drop CVE-2019-13626.patch, CVE-2019-7636.patch,
  CVE-2019-7635.patch.
* Sat Jul 20 2019 Michael Gorse <mgorse@suse.com>
- Add CVE-2019-13626.patch: add safeguards to the wav parser to
  prevent crashes (boo#1142031 CVE-2019-13626).
- Drop CVE-2019-7572.patch, CVE-2019-7574.patch,
  CVE-2019-7575.patch, CVE-2019-7577.patch, and
  CVE-2019-7578.patch: these are handled by the new code added in
  CVE-2019-13626.patch.
* Thu May 23 2019 Qiang Zheng <qzheng@suse.com>
- Remove CVE-2019-7637.patch, the modification of function
  SDL_CalculatePitch is only suit for SDL not SDL2.
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7636.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7636, boo#1124826, CVE-2019-7638, boo#1124824).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7635.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7635, boo#1124827).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7578.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7578, boo#1125099, CVE-2019-7576, boo#1124799
  CVE-2019-7573, boo#1124805).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7572.patch to fix a buffer over-read issue
  (CVE-2019-7572, boo#1124806).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7574.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7574, boo#1124803).
* Thu Feb 28 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7575.patch to fix a heap-based buffer overflow
  issue (CVE-2019-7575, boo#1124802).
* Thu Feb 28 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7637.patch to fix a heap-base buffer overflow
  issue (CVE-2019-7637, boo#1124825).
* Wed Feb 27 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7577.patch to fix a buffer over-read issue
  (CVE-2019-7577, boo#1124800).
* Sun Nov  4 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.9
  * Added a new sensor API, initialized by passing
    SDL_INIT_SENSOR to SDL_Init(), and defined in SDL_sensor.h
  * Added an event SDL_SENSORUPDATE which is sent when a sensor
    is updated
  * Added SDL_GetDisplayOrientation() to return the current
    display orientation
  * Added an event SDL_DISPLAYEVENT which is sent when the
    display orientation changes
  * Added HIDAPI joystick drivers for more consistent support
    for Xbox, PS4 and Nintendo Switch Pro controller support
    across platforms. (Thanks to Valve for contributing the PS4
    and Nintendo Switch Pro controller support)
  * Added support for many other popular game controllers
  * Added SDL_JoystickGetDevicePlayerIndex(),
    SDL_JoystickGetPlayerIndex(), and
    SDL_GameControllerGetPlayerIndex() to get the player index for
    a controller. For XInput controllers this returns the XInput
    index for the controller.
  * Added SDL_GameControllerRumble() and SDL_JoystickRumble()
    which allow simple rumble without using the haptics API
  * Added SDL_GameControllerMappingForDeviceIndex() to get the
    mapping for a controller before it's opened
  * Added the hint SDL_HINT_MOUSE_DOUBLE_CLICK_TIME to control
    the mouse double-click time
  * Added the hint SDL_HINT_MOUSE_DOUBLE_CLICK_RADIUS to control
    the mouse double-click radius, in pixels
  * Added SDL_HasColorKey() to return whether a surface has a
    colorkey active
  * Added SDL_HasAVX512F() to return whether the CPU has
    AVX-512F features
  * Added SDL_IsTablet() to return whether the application is
    running on a tablet
  * Added SDL_THREAD_PRIORITY_TIME_CRITICAL for threads that
    must run at the highest priority
  * Added SDL_LinuxSetThreadPriority() to allow adjusting the
    thread priority of native threads using RealtimeKit if
    available.
- Dropped 7babfecee045.patch (merged upstream)
* Sun Jun 24 2018 robert.munteanu@gmail.com
- Add 7babfecee045.patch, fixes launching Firewatch
* Fri May 11 2018 crrodriguez@opensuse.org
- SDL2-endian.patch: bring up patch from SDL1, use optimized
  byteswap routines from the C library.
- build with --disable-3dnow, do not pass -m3dnow to the compiler
  modern cpus do not support this instructions at all.
* Sat Mar 17 2018 ytz1995@hotmail.com
- Build with Wayland support
* Thu Mar  8 2018 jengelh@inai.de
- Update to new upstream release 2.0.8
  * Added SDL_fmod() and SDL_log10().
  * Each of the SDL math functions now has the corresponding
    float version.
  * Added SDL_SetYUVConversionMode() and
    SDL_GetYUVConversionMode() to control the formula used when
    converting to and from YUV colorspace. The options are JPEG,
    BT.601, and BT.709.
  * Added the hint SDL_HINT_VIDEO_X11_NET_WM_BYPASS_COMPOSITOR to
    control whether the X server should skip the compositor for
    the SDL application. This defaults to "1".
  * Added the hint SDL_HINT_VIDEO_DOUBLE_BUFFER to control
    whether the Raspberry Pi and KMSDRM video drivers should use
    double or triple buffering (the default).
* Wed Jan 10 2018 jengelh@inai.de
- Add sdl2-symvers.patch.
* Sat Oct 28 2017 adam@mizerski.pl
- update to 2.0.7
  * Added audio stream conversion functions.
  * Added functions to query and set the SDL memory allocation
    functions.
  * Added locking functions for multi-threaded access to
    the joystick and game controller APIs.
  * Some functions are now thread-safe.
- removed patches, merged upstream
  * dbus.diff
  * SDL2-ppc64-declaration-after-statement.patch
  * SDL-bnc1062784-check-overflow-xcf-props.patch
* Thu Oct 19 2017 sreeves@suse.com
- Add SDL-bnc1062784-check-overflow-xcf-props.patch. CVE-2017-2888
* Mon Oct 16 2017 wbauer@tmo.at
- Disable SSE3 (and also SSE2 on ix86) to prevent crashes on older
  CPUs that don't support these instructions
* Mon Oct  2 2017 jengelh@inai.de
- Add dbus.diff
* Mon Oct  2 2017 guillaume@opensuse.org
- Enable KMS/DRM video driver
* Sat Sep 30 2017 spartanj@gmail.com
- Update to new upstream release 2.0.6
  * Added Vulkan graphics support in SDL_vulkan.h.
  * Added SDL_ComposeCustomBlendMode() to create custom blend
    modes for 2D rendering.
  * Added support for many game controllers, including the
    Nintendo Switch Pro Controller.
  * Added support for inverted axes and separate axis directions
    in game controller mappings.
  * Added functions to return information about joysticks and
    open game controllers.
  * Added SDL_GameControllerNumMappings() and
    SDL_GameControllerMappingForIndex() to be able to enumerate
    the built-in game controller mappings.
  * Added SDL_LoadFile() and SDL_LoadFile_RW() to load a file
    into memory.
  * Added SDL_DuplicateSurface() to make a copy of a surface.
  * Added an experimental JACK audio driver.
  * Implemented non-power-of-two audio resampling.
  * Added the hint SDL_HINT_AUDIO_RESAMPLING_MODE to control the
    quality of resampling.
  * Added the hint SDL_HINT_RENDER_LOGICAL_SIZE_MODE to control
    the scaling policy for SDL_RenderSetLogicalSize().
  * Added the hints SDL_HINT_MOUSE_NORMAL_SPEED_SCALE and
    SDL_HINT_MOUSE_RELATIVE_SPEED_SCALE to scale the mouse speed
    when being read from raw mouse input.
  * Added the hint SDL_HINT_TOUCH_MOUSE_EVENTS to control whether
    SDL will synthesize mouse events from touch events.
  * Added an experimental KMS/DRM video driver for embedded
    development.
- Remove dbus-ime.diff (no longer needed)
* Tue Aug  1 2017 fcrozat@suse.com
- Do not BuildRequires pkgconfig(fcitx) on SLE (not shipped anymore
  since SLE12 SP2).
* Thu Jun 29 2017 schwab@suse.de
- libspe2 doesn't exist any more
* Wed Feb 15 2017 jengelh@inai.de
- Add dbus-ime.diff and build with fcitx [boo#1025413]
* Sun Oct 23 2016 aloisio@gmx.com
- Backported commit 5184186d4366 and fbf9b0e3589a as
  SDL2-ppc64-declaration-after-statement.patch to fix build
  on ppc64/ppc64le
* Thu Oct 20 2016 aloisio@gmx.com
- Update to 2.0.5
  General:
  * Implemented audio capture support for some platforms
  * Added SDL_DequeueAudio() to retrieve audio when buffer
    queuing is turned on for audio capture
  * Added events for dragging and dropping text
  * Added events for dragging and dropping multiple items
  * By default the click raising a window will not be
    delivered to the SDL application. You can set the hint
    SDL_HINT_MOUSE_FOCUS_CLICKTHROUGH to "1" to allow that click
    through to the window.
  * Saving a surface with an alpha channel as a BMP will use a
    newer BMP format that supports alpha information. You can
    set the hint SDL_HINT_BMP_SAVE_LEGACY_FORMAT to "1" to use
    the old format.
  * Added SDL_GetHintBoolean() to get the boolean value of a
    hint
  * Added SDL_RenderSetIntegerScale() to set whether to
    smoothly scale or use integral multiples of the viewport
    size when scaling the rendering output
  * Added SDL_CreateRGBSurfaceWithFormat() and
    SDL_CreateRGBSurfaceWithFormatFrom() to create an SDL
    surface with a specific pixel format
  * Added SDL_GetDisplayUsableBounds() which returns the area
    usable for windows. For example, on Mac OS X, this subtracts
    the area occupied by the menu bar and dock.
  * Added SDL_GetWindowBordersSize() which returns the size of
    the window's borders around the client area
  * Added a window event SDL_WINDOWEVENT_HIT_TEST when a
    window had a hit test that wasn't SDL_HITTEST_NORMAL (e.g.
    in the title bar or window frame)
  * Added SDL_SetWindowResizable() to change whether a window
    is resizable
  * Added SDL_SetWindowOpacity() and SDL_GetWindowOpacity() to
    affect the window transparency
  * Added SDL_SetWindowModalFor() to set a window as modal for
    another window
  * Added support for AUDIO_U16LSB and AUDIO_U16MSB to
    SDL_MixAudioFormat()
  * Fixed flipped images when reading back from target
    textures when using the OpenGL renderer
  * Fixed texture color modulation with SDL_BLENDMODE_NONE
    when using the OpenGL renderer
  * Fixed bug where the alpha value of colorkeys was ignored
    when blitting in some cases
  Linux:
  * Added support for the Fcitx IME
  * Added a window event SDL_WINDOWEVENT_TAKE_FOCUS when a
    window manager asks the SDL window whether it wants to take
    focus.
  * Refresh rates are now rounded instead of truncated, e.g.
    59.94 Hz is rounded up to 60 Hz instead of 59.
  * Added initial support for touchscreens on Raspberry Pi
* Thu Mar 17 2016 mpluskal@suse.com
- Make building more verbose
* Thu Mar 10 2016 jengelh@inai.de
- Enable udev support
* Sun Jan 10 2016 mailaender@opensuse.org
- update to version 2.0.4
  General:
  * Added support for web applications using Emscripten, see
    docs/README-emscripten.md for more information
  * Added support for web applications using Native Client (NaCl), see
    docs/README-nacl.md for more information
  * Added an API to queue audio instead of using the audio callback:
    SDL_QueueAudio(), SDL_GetQueuedAudioSize(), SDL_ClearQueuedAudio()
  * Added events for audio device hot plug support:
    SDL_AUDIODEVICEADDED, SDL_AUDIODEVICEREMOVED
  * Added SDL_PointInRect()
  * Added SDL_HasAVX2() to detect CPUs with AVX2 support
  * Added SDL_SetWindowHitTest() to let apps treat parts of their SDL window
    like traditional window decorations (drag areas, resize areas)
  * Added SDL_GetGrabbedWindow() to get the window that currently has input
    grab, if any
  * Added SDL_RenderIsClipEnabled() to tell whether clipping is currently
    enabled in a renderer
  * Added SDL_CaptureMouse() to capture the mouse to get events while the
    mouse is not in your window
  * Added SDL_WarpMouseGlobal() to warp the mouse cursor in global screen
    space
  * Added SDL_GetGlobalMouseState() to get the current mouse state outside of
    an SDL window* Added a direction field to mouse wheel events to tell
    whether they are flipped (natural) or not
  * Added GL_CONTEXT_RELEASE_BEHAVIOR GL attribute (maps to
    [WGL|GLX]_ARB_context_flush_control extension)
  * Added EGL_KHR_create_context support to allow OpenGL ES version selection
    on some platforms* Added NV12 and NV21 YUV texture support for OpenGL and
    OpenGL ES 2.0 renderers
  * Added a Vivante video driver that is used on various SoC platforms
  * Added an event SDL_RENDER_DEVICE_RESET that is sent from the D3D
    renderers when the D3D device is lost, and from Android's event loop when
    the GLES context had to be recreated
  * Added a hint SDL_HINT_NO_SIGNAL_HANDLERS to disable SDL's built in signal
    handling* Added a hint SDL_HINT_THREAD_STACK_SIZE to set the stack size of
    SDL's threads
  * Added SDL_sqrtf(), SDL_tan(), and SDL_tanf() to the stdlib routines
  * Improved support for WAV and BMP files with unusual chunks in them
  * Renamed SDL_assert_data to SDL_AssertData and SDL_assert_state to
    SDL_AssertState
  * Added a hint SDL_HINT_WINDOW_FRAME_USABLE_WHILE_CURSOR_HIDDEN to prevent
    window interaction while cursor is hidden
  * Added SDL_GetDisplayDPI() to get the DPI information for a display* Added
    SDL_JoystickCurrentPowerLevel() to get the battery level of a joystick
  * Added SDL_JoystickFromInstanceID(), as a helper function, to get the
    SDL_Joystick* that an event is referring to.
  * Added SDL_GameControllerFromInstanceID(), as a helper function, to get
    the SDL_GameController* that an event is referring to.
* Mon Jan 12 2015 schwab@suse.de
- libspe2 only exists for ppc and ppc64
* Fri Dec 19 2014 jengelh@inai.de
- Drop old arts/esound soundserver support.
* Thu Dec 18 2014 jengelh@inai.de
- Remove SDL2 obsoletes (we never had packages of that name).
  Copy current Provides to baselibs.conf.
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 2.0.3
  * This is a minor bugfix release to take care of creating an OpenGL
  context on Mac OS X.
* Mon May 26 2014 mailaender@opensuse.org
- Added missing build dependencies
  * arts
  * dbus
  * udev
  * tslib
- Removed unrecognized options: --disable-video-svga, --disable-video-ps3
* Mon May 26 2014 mailaender@opensuse.org
- Use pkgconfig everywhere
- Fix the build on SLE using prjconf
* Thu Mar 13 2014 mailaender@opensuse.org
- Update to 2.0.2
  * Added SDL_GL_ResetAttributes() to reset OpenGL attributes to default values
  * Added an API to load a database of game controller mappings from a file:
    SDL_GameControllerAddMappingsFromFile(), SDL_GameControllerAddMappingsFromRW()
  * Added game controller mappings for the PS4 and OUYA controllers
  * Added SDL_GetDefaultAssertionHandler() and SDL_GetAssertionHandler()
  * Added SDL_DetachThread()
  * Added SDL_HasAVX() to determine if the CPU has AVX features
  * Added SDL_vsscanf(), SDL_acos(), and SDL_asin() to the stdlib routines
  * EGL can now create/manage OpenGL and OpenGL ES 1.x/2.x contexts, and share
    them using SDL_GL_SHARE_WITH_CURRENT_CONTEXT
  * Added a field "clicks" to the mouse button event which records whether the event is a single click, double click, etc.
  * The screensaver is now disabled by default, and there is a hint SDL_HINT_VIDEO_ALLOW_SCREENSAVER that can change that behavior.
  * Added a hint SDL_HINT_MOUSE_RELATIVE_MODE_WARP to specify whether mouse relative mode should be emulated using mouse warping.
  * testgl2 does not need to link with libGL anymore
  * Added testgles2 test program to demonstrate working with OpenGL ES 2.0
  * Added controllermap test program to visually map a game controller
  * Fixed fullscreen and focused behavior when receiving NotifyGrab events
  * Added experimental Wayland and Mir support, disabled by default
- Added SDL2-devel provides
* Thu Nov  7 2013 mailaender@opensuse.org
- Update to version 2.0.1:
  * Added an API to get common filesystem paths in SDL_filesystem.h:
    SDL_GetBasePath(), SDL_GetPrefPath()
  * Added an API to do optimized YV12 and IYUV texture updates:
    SDL_UpdateYUVTexture()
  * Added an API to get the amount of RAM on the system:
    SDL_GetSystemRAM()
  * Added a macro to perform timestamp comparisons with SDL_GetTicks():
    SDL_TICKS_PASSED()
  * Dramatically improved OpenGL ES 2.0 rendering performance
  * Added OpenGL attribute SDL_GL_FRAMEBUFFER_SRGB_CAPABLE
  * Fixed float audio support with the PulseAudio driver
  * Fixed missing line endpoints in the OpenGL renderer on some drivers
  * X11 symbols are no longer defined to avoid collisions when linking statically
* Mon Oct 28 2013 prusnak@opensuse.org
- add SDL2 provides
* Tue Aug 13 2013 jengelh@inai.de
- Some metadata spruce-up: add current URLs, softer wildcarding
  in the files list, more robust make install call
- Reduce build dependencies
- Optional signature verification in local builds
* Tue Aug 13 2013 prusnak@opensuse.org
- created package (version 2.0.0) - based on SDL package
